// This file was autogenerated. Do not edit it manually.
## Device List
### ophyd_devices 
| Device | Documentation | Module |
| :----- | :------------- | :------ |
| Andor3DetectorCam | <br>    ADAndor3 driver, https://github.com/areaDetector/ADAndor3<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(Andor3DetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| AravisDetectorCam | <br>    ADAravis driver, https://github.com/areaDetector/ADAravis<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(AravisDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| ASItpxCam | <br>    ASI Timepix detector driver, https://github.com/paulscherrerinstitute/ADASItpx<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(ASItpxCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| AttributePlugin_V35 | <br>    Plugin to extract NDArray attributes and publish their values over channel access,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginAttribute.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            attr = Cpt(AttributePlugin_V35, 'Attr1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| AttrPlotPlugin_V35 | <br>    Plugin to retrieve NDAttribute values, cache them and expose them as a waveform,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginAttrPlot.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            attrplot = Cpt(AttrPlotPlugin_V35, 'AttrPlot1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| BadPixelPlugin | <br>    Plugin to replace bad pixels in an NDArray,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginBadPixel.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            baxpixel = Cpt(BadPixelPlugin, 'BadPix1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| CamBase | <br>    Base class for all camera drivers.<br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| CircularBuffPlugin_V35 | <br>    Plugin to check a user-defined trigger condition has been met and output triggering NDArray,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginCircularBuff.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            cb = Cpt(CircularBuffPlugin_V35, 'CB1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| CodecPlugin_V35 | <br>    Plugin to compress and decompress NDArray data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginCodec.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            codec = Cpt(CodecPlugin_V35, 'Codec1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ColorConvPlugin_V35 | <br>    Plugin to convert the color mode of NDArray data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginColorConvert.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            cc = Cpt(ColorConvPlugin_V35, 'CC1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| DelayGenerator | Delay Generator Stanford Research DG645. This implements an interface for the DG645 delay generator.<br><br>    The DG645 has 8 channels, each with a delay and pulse width. The channels are implemented as DelayPair objects (AB etc.).<br><br>    Signal pairs, e.g. AB, CD, EF, GH, are implemented as DelayPair objects. They<br>    have a TTL pulse width, delay and a reference signal to which they are being triggered.<br>    In addition, the io layer allows setting amplitude, offset and polarity for each pair.<br><br>    Detailed information can be found in the manual:<br>    https://www.thinksrs.com/downloads/pdfs/manuals/DG645m.pdf<br>     | [ophyd_devices.devices.delay_generator_645](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/delay_generator_645.py) |
| DelayPair | <br>    Delay pair interface<br><br>    Virtual motor interface to a pair of signals (on the frontpanel - AB/CD/EF/GH).<br>    It offers a simple delay and pulse width interface.<br>     | [ophyd_devices.devices.delay_generator_645](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/delay_generator_645.py) |
| DelayStatic | <br>    Static axis for the T0 output channel<br><br>    It allows setting the logic levels, but the timing is fixed.<br>    The signal is high after receiving the trigger until the end<br>    of the holdoff period.<br>     | [ophyd_devices.devices.delay_generator_645](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/delay_generator_645.py) |
| DummyPositioner | Dummy Positioner to set AO, AI and ReferenceMO. | [ophyd_devices.devices.delay_generator_645](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/delay_generator_645.py) |
| EigerDetectorCam | <br>    ADEiger driver, https://github.com/areaDetector/ADEiger<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(EigerDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| EpicsDXPFalcon | All high-level DXP parameters for each channel | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| EpicsDxpFalconMapping | Mapping mode parameters as defined in dxpMapping.template | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| EpicsDXPFalconMultiElementSystem | System-wide parameters as defined in dxpMED.template | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| EpicsDXPMultiElementSystem | System-wide parameters as defined in dxpMED.template | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| EpicsMCARecord | EpicsMCARecord with addtional fields | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| EpicsMotorEx | Extend EpicsMotor with extra configuration fields.<br>    motor_done_move<br>    motor_is_moving<br>     | [ophyd_devices.devices.epics_motor_ex](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/epics_motor_ex.py) |
| Falcon | Falcon base device | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| FFTPlugin_V35 | <br>    Plugin to compute 1-D or 2-D Fast Fourier Transforms,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginFFT.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            fft = Cpt(FFTPlugin_V35, 'FFT1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| FileBase | <br>    File saving parameters.<br><br>    It is not meant to be used directly, but rather through inheritance by camera drivers<br>    with file saving support, e.g. PilatusDetectorCam and SLSDetectorCam<br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| FilePlugin_V35 | <br>    Base class for all file plugins.<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| GatherNPlugin_V35 | <br>    Part of GatherPlugin.<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| GatherPlugin_V35 | <br>    Plugin to to gather NDArrays from multiple upstream plugins and merge them into a single stream,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginGather.html.<br><br>    ::<br>        class MyGatherPlugin(GatherPlugin_V35):<br>            gather1 = Cpt(GatherNPlugin_V35, '', index=1)<br>            gather2 = Cpt(GatherNPlugin_V35, '', index=2)<br><br>        class MyDetector(ADBase):<br>            gather = Cpt(MyGatherPlugin, 'Gather1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| GenICam | <br>    ADGenICam driver, https://github.com/areaDetector/ADGenICam<br><br>    It is the base class for GenICam drivers and not meant to be used directly.<br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| HDF5Plugin_V35 | <br>    Plugin to save data in HDF5 format,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileHDF5.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            hdf = Cpt(HDF5Plugin_V35, 'HDF1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ImagePlugin_V35 | <br>    Plugin to convert the NDArray data into a form accessible by EPICS Channel Access clients,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginStdArrays.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            image = Cpt(ImagePlugin_V35, 'image1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| JPEGPlugin_V35 | <br>    Plugin to save data in JPEG format,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileJPEG.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            jpeg = Cpt(JPEGPlugin_V35, 'JPEG1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| MagickPlugin_V35 | <br>    Plugin to save data in any format supported by ImageMagick/GraphicsMagick,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileMagick.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            magick = Cpt(MagickPlugin_V35, 'Magick1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| Mercury | Mercury base device | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| NetCDFPlugin_V35 | <br>    Plugin to save data in netCDF format,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileNetCDF.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            netcdf = Cpt(NetCDFPlugin_V35, 'netCDF1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| NexusPlugin_V35 | <br>    Plugin to save data in NeXus format,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileNexus.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            nexus = Cpt(NexusPlugin_V35, 'Nexus1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| OverlayPlugin_V35 | <br>    Plugin to add graphics overlay to image data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginOverlay.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            overlay = Cpt(OverlayPlugin_V35, 'Over1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| PilatusDetectorCam | <br>    ADPilatus driver, https://github.com/areaDetector/ADPilatus<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(PilatusDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| PluginBase_V35 | <br>    Base class for all plugins.<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| PosPluginPlugin_V35 | <br>    Plugin to attach positional information to NDArrays in the form of NDAttributes,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginPos.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            pos = Cpt(PosPluginPlugin_V35, 'Pos1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ProcessPlugin_V313 | <br>    Plugin to perform arithmetic processing on NDArray data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginProcess.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            process = Cpt(ProcessPlugin_V35, 'Proc1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ProsilicaDetectorCam | <br>    ADProsilica driver, https://github.com/areaDetector/ADProsilica<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(ProsilicaDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| PvaPlugin_V35 | <br>    Plugin to convert NDArray into NTNDArray accessible by PVAccess clients,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginPva.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            pva = Cpt(PvaPlugin_V35, 'Pva1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| PylonDetectorCam | <br>    ADPylon driver, https://github.com/areaDetector/ADPylon<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(PylonDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| ROI | ROI for DXP system with proper Kind settings. | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
| ROIPlugin_V35 | <br>    Plugin to select a ROI from NDArray data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginROI.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            roi1 = Cpt(ROIPlugin_V35, 'ROI1:')<br>            roi2 = Cpt(ROIPlugin_V35, 'ROI2:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ROIStatNPlugin_V35 | <br>    Part of ROIStatPlugin<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ROIStatPlugin_V35 | <br>    Plugin to calculate statistics for multiple ROIs,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginROIStat.html.<br><br>    ::<br><br>        class MyROIStatPlugin(ROIStatPlugin_V35):<br>            roi1 = Cpt(ROIStatNPlugin_V35, '1:')<br>            roi2 = Cpt(ROIStatNPlugin_V35, '2:')<br><br>        class MyDetector(ADBase):<br>            roistat = Cpt(MyROIStatPlugin, 'ROIStat1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| ScatterPlugin_V35 | <br>    Plugin to distribute the processing of NDArrays to multiple downstream plugins,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginScatter.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            scatter = Cpt(ScatterPlugin_V35, 'Scatter1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| SimDetectorCam | <br>    ADSimDetector driver, https://github.com/areaDetector/ADSimDetector<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(SimDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| SLSDetectorCam | <br>    slsDetector driver, https://github.com/paulscherrerinstitute/slsDetector<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(SLSDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| SLSInfo |  | [ophyd_devices.devices.sls_devices](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_devices.py) |
| SLSOperatorMessages |  | [ophyd_devices.devices.sls_devices](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_devices.py) |
| SpmBase | Python wrapper for the Staggered Blade Pair Monitors<br><br>    SPM's consist of a set of four horizontal tungsten blades and are<br>    used to monitor the beam height (only Y) for the bending magnet<br>    beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the users can<br>    change the beam position offset.<br>     | [ophyd_devices.devices.SpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/SpmBase.py) |
| SpmSim | Python wrapper for simulated Staggered Blade Pair Monitors<br><br>    SPM's consist of a set of four horizontal tungsten blades and are<br>    used to monitor the beam height (only Y) for the bending magnet<br>    beamlines of SLS.<br><br>    This simulation device extends the basic proxy with a script that<br>    fills signals with quasi-randomized values.<br>     | [ophyd_devices.devices.SpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/SpmBase.py) |
| StatsPlugin_V35 | <br>    Plugin to calculate statistics on NDArray data,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginStats.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            stats = Cpt(StatsPlugin_V35, 'Stats1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| TIFFPlugin_V35 | <br>    Plugin to save data in TIFF format,<br>    https://areadetector.github.io/areaDetector/ADCore/NDFileTIFF.html.<br><br>    ::<br><br>        class MyDetector(ADBase):<br>            tiff = Cpt(TIFFPlugin_V35, 'TIFF1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| TimeSeriesPlugin_V35 | <br>    Plugin to create time-series data of input signals,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginTimeSeries.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            ts = Cpt(TimeSeriesPlugin_V35, 'TS:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| TransformPlugin_V35 | <br>    Plugin to rotate/flip the image,<br>    https://areadetector.github.io/areaDetector/ADCore/NDPluginTransform.html.<br><br>    ::<br>        class MyDetector(ADBase):<br>            transform = Cpt(TransformPlugin_V35, 'Trans1:')<br>     | [ophyd_devices.devices.areadetector.plugins](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/plugins.py) |
| URLDetectorCam | <br>    ADURL driver, https://github.com/areaDetector/ADURL<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(AravisDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| VimbaDetectorCam | <br>    ADVimba driver, https://github.com/areaDetector/ADVimba<br><br>    ::<br><br>        from ophyd import Component as Cpt<br><br>        class MyDetector(ADBase):<br>            cam = Cpt(VimbaDetectorCam, 'cam1:')<br><br>     | [ophyd_devices.devices.areadetector.cam](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/areadetector/cam.py) |
| XbpmBase | Python wrapper for X-ray Beam Position Monitors<br><br>    XBPM's consist of a metal-coated diamond window that ejects<br>    photoelectrons from the incoming X-ray beam. These electons<br>    are collected and their current is measured. Effectively<br>    they act as four quadrant photodiodes and are used as BPMs<br>    at the undulator beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the user can<br>    change the beam position offset.<br>     | [ophyd_devices.devices.XbpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/XbpmBase.py) |
| XbpmSim | Python wrapper for simulated X-ray Beam Position Monitors<br><br>    XBPM's consist of a metal-coated diamond window that ejects<br>    photoelectrons from the incoming X-ray beam. These electons<br>    are collected and their current is measured. Effectively<br>    they act as four quadrant photodiodes and are used as BPMs<br>    at the undulator beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the user can<br>       change the beam position offset.<br><br>    This simulation device extends the basic proxy with a script that<br>    fills signals with quasi-randomized values.<br>     | [ophyd_devices.devices.XbpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/XbpmBase.py) |
| xMAP | xMAP base device | [ophyd_devices.devices.dxp](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/dxp.py) |
